@@ -93,11 +93,11 @@ namespace Arcus
         #ifdef ARCUS_DEBUG
         void debug(const std::string& message);
         #endif
-        void error(ErrorCode::ErrorCode error_code, const std::string& message);
-        void fatalError(ErrorCode::ErrorCode error_code, const std::string& msg);
+        void error(ErrorCode error_code, const std::string& message);
+        void fatalError(ErrorCode error_code, const std::string& msg);
 
-        SocketState::SocketState state;
-        SocketState::SocketState next_state;
+        SocketState state;
+        SocketState next_state;
 
         bool received_close;
 
@@ -148,7 +148,7 @@ namespace Arcus
     #endif
 
     // Report an error that should not cause the connection to abort.
-    void Socket::Private::error(ErrorCode::ErrorCode error_code, const std::string& message)
+    void Socket::Private::error(ErrorCode error_code, const std::string& message)
     {
         Error error(error_code, message);
         error.setNativeErrorCode(platform_socket.getNativeErrorCode());
@@ -162,7 +162,7 @@ namespace Arcus
     }
 
     // Report an error that should cause the socket to go into an error state and abort the connection.
-    void Socket::Private::fatalError(ErrorCode::ErrorCode error_code, const std::string& message)
+    void Socket::Private::fatalError(ErrorCode error_code, const std::string& message)
     {
         Error error(error_code, message);
         error.setFatalError(true);
